@@ -33,7 +33,6 @@
 #include "cursorthemesmodel.h"
 
 class KProcess;
-class QX11EmbedContainer;
 namespace Ui { class Modulo; class GUI; }
 
 class GTKConfigKCModule : public KCModule
@@ -72,6 +71,7 @@ signals:
     
 private:
     void syncUI();
+    bool m_loading = false;
     
     Ui::GUI *ui;
     AppearenceGTK *appareance;
